/*
 * Copyright (C) 2010 Teleal GmbH, Switzerland
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation, either version 3 of
 * the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

package org.teleal.cling.model;

import org.teleal.common.util.URIUtil;

import java.net.InetAddress;
import java.net.URI;
import java.net.URL;

/**
 * @author Christian Bauer
 */
public class Locator {

    protected InetAddress address;
    protected int port;
    protected URI path;
    protected byte[] hardwareAddress;

    public Locator(InetAddress address, int port, URI path) {
        this(address, port, path, null);
    }

    public Locator(InetAddress address, int port, URI path, byte[] hardwareAddress) {
        this.address = address;
        this.port = port;
        this.path = path;
        this.hardwareAddress = hardwareAddress;
    }

    public InetAddress getAddress() {
        return address;
    }

    public int getPort() {
        return port;
    }

    public URI getPath() {
        return path;
    }

    public byte[] getHardwareAddress() {
        return hardwareAddress;
    }

    public URL getURL() {
        return URIUtil.createAbsoluteURL(address, port, getPath());
    }

}
