/*
 * Copyright (C) 2010 Teleal GmbH, Switzerland
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation, either version 3 of
 * the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

package org.teleal.cling.transport;

import org.teleal.cling.UpnpServiceConfiguration;
import org.teleal.cling.model.message.IncomingDatagramMessage;
import org.teleal.cling.model.message.OutgoingDatagramMessage;
import org.teleal.cling.model.message.StreamRequestMessage;
import org.teleal.cling.model.message.StreamResponseMessage;
import org.teleal.cling.protocol.ProtocolFactory;
import org.teleal.cling.transport.spi.NetworkAddressFactory;
import org.teleal.cling.transport.spi.StreamClient;
import org.teleal.cling.transport.spi.UpnpStream;

import java.net.InetAddress;


public interface Router {

    public UpnpServiceConfiguration getConfiguration();
    public ProtocolFactory getProtocolFactory();

    public StreamClient getStreamClient();
    public NetworkAddressFactory getNetworkAddressFactory();

    public int getLocalStreamPort(InetAddress address);

    public void shutdown();

    public void received(IncomingDatagramMessage msg);

    public void received(UpnpStream stream);

    public void send(OutgoingDatagramMessage msg);

    public StreamResponseMessage send(StreamRequestMessage msg);

    public void broadcast(byte[] bytes);

}
